@@ -16,8 +16,11 @@ from .SWIRModel import SWIRModel
 from .ThresholdModel import ThresholdModel
 from .ICEModel import ICEModel
 from .ICPModel import ICPModel
+from .ICEPModel import ICEPModel
 from .GeneralThresholdModel import GeneralThresholdModel
 from .UTLDRModel import UTLDRModel
+from .SEIR_ct_Model import SEIRctModel
+from .SEIS_ct_Model import SEISctModel
 
 __all__ = [
     'GeneralisedThresholdModel',
@@ -35,5 +38,8 @@ __all__ = [
     'ICEModel',
     'ICPModel',
     'GeneralThresholdModel',
-    'UTLDRModel'
+    'UTLDRModel',
+    'ICEPModel',
+    'SEIRctModel',
+    'SEISctModel'
 ]
