@@ -12,6 +12,10 @@ from .MajorityRuleModel import MajorityRuleModel
 from .QVoterModel import QVoterModel
 from .SznajdModel import SznajdModel
 from .VoterModel import VoterModel
+from .WHKModel import WHKModel
+from .ARWHKModel import ARWHKModel
+from .HKModel import HKModel
+
 
 __all__ = [
     'AlgorithmicBiasModel',
@@ -20,4 +24,7 @@ __all__ = [
     'QVoterModel',
     'SznajdModel',
     'VoterModel',
+    'WHKModel',
+    'ARWHKModel',
+    'HKModel'
 ]
